go-tebex

command module
v0.0.0-...-c7694f1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2021 License: MIT Imports: 6 Imported by: 0

README

go-tebex

A golang library for accessing tebex api easily

but why go?

because dragonfly uses golang and this would make it easier for dragonfly server owners to access the api

TODO: Alot todo at the moment
Examples
Server Information
package main

import "github.com/moonlightpe/go-tebex"

func main() {
	session, err := go-tebex.New("API KEY")
	if err != nil {
		panic(err)
	}
	info, err := session.GetInformation()
	if err != nil {
		panic(err)
	}

	fmt.Println(info)
}

Documentation

The Go Gopher

There is no documentation for this package.

Jump to